@@ -2,6 +2,7 @@
 import logging
 from typing import Any
 from typing import Callable
+from typing import cast
 from typing import Optional
 
 from lexicon.providers import dnsmadeeasy
@@ -62,8 +63,8 @@ class Authenticator(dns_common.DNSAuthenticator):
     def _get_dnsmadeeasy_client(self) -> "_DNSMadeEasyLexiconClient":
         if not self.credentials:  # pragma: no cover
             raise errors.Error("Plugin has not been prepared.")
-        return _DNSMadeEasyLexiconClient(self.credentials.conf('api-key'),
-                                         self.credentials.conf('secret-key'),
+        return _DNSMadeEasyLexiconClient(cast(str, self.credentials.conf('api-key')),
+                                         cast(str, self.credentials.conf('secret-key')),
                                          self.ttl)
 
 
